==> huaweicloudsdkiam-3.0.46-py2.py3-none-any.whl: huaweicloudsdkiam/v3/model/keystone_update_mapping_request.py <==
# coding: utf-8

import pprint
import re

import six





class KeystoneUpdateMappingRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'id': 'str',
        'body': 'KeystoneUpdateMappingRequestBody'
    }

    attribute_map = {
        'id': 'id',
        'body': 'body'
    }

    def __init__(self, id=None, body=None):
        """KeystoneUpdateMappingRequest - a model defined in huaweicloud sdk"""
        
        

        self._id = None
        self._body = None
        self.discriminator = None

        self.id = id
        if body is not None:
            self.body = body

    @property
    def id(self):
        """Gets the id of this KeystoneUpdateMappingRequest.

        待更新的映射ID。

        :return: The id of this KeystoneUpdateMappingRequest.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this KeystoneUpdateMappingRequest.

        待更新的映射ID。

        :param id: The id of this KeystoneUpdateMappingRequest.
        :type: str
        """
        self._id = id

    @property
    def body(self):
        """Gets the body of this KeystoneUpdateMappingRequest.


        :return: The body of this KeystoneUpdateMappingRequest.
        :rtype: KeystoneUpdateMappingRequestBody
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this KeystoneUpdateMappingRequest.


        :param body: The body of this KeystoneUpdateMappingRequest.
        :type: KeystoneUpdateMappingRequestBody
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KeystoneUpdateMappingRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiam-3.0.52-py2.py3-none-any.whl: huaweicloudsdkiam/v3/model/keystone_update_mapping_request.py <==
# coding: utf-8

import re
import six





class KeystoneUpdateMappingRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'id': 'str',
        'body': 'KeystoneUpdateMappingRequestBody'
    }

    attribute_map = {
        'id': 'id',
        'body': 'body'
    }

    def __init__(self, id=None, body=None):
        """KeystoneUpdateMappingRequest - a model defined in huaweicloud sdk"""
        
        

        self._id = None
        self._body = None
        self.discriminator = None

        self.id = id
        if body is not None:
            self.body = body

    @property
    def id(self):
        """Gets the id of this KeystoneUpdateMappingRequest.

        待更新的映射ID。

        :return: The id of this KeystoneUpdateMappingRequest.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this KeystoneUpdateMappingRequest.

        待更新的映射ID。

        :param id: The id of this KeystoneUpdateMappingRequest.
        :type: str
        """
        self._id = id

    @property
    def body(self):
        """Gets the body of this KeystoneUpdateMappingRequest.


        :return: The body of this KeystoneUpdateMappingRequest.
        :rtype: KeystoneUpdateMappingRequestBody
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this KeystoneUpdateMappingRequest.


        :param body: The body of this KeystoneUpdateMappingRequest.
        :type: KeystoneUpdateMappingRequestBody
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KeystoneUpdateMappingRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
